@@ -1,3 +1,31 @@
+# lookup_acs5year_2018 =========================================================
+#' ACS 5-year 2018 file segment and table lookup data
+#'
+#' @docType data
+#'
+#' @format A data.table with 26996 rows and 7 variables
+#' \describe{
+#'   \item{file_segment}{sequence number of segment data files, from "0001" to "0122"}
+#'   \item{table_content}{description of columns in a table}
+#'   \item{reference}{reference of the table content, such as "B01001_002". The reference
+#'         is used to extract data of table content.}
+#'   \item{restriction}{restrictions applied the the table_content}
+#'   \item{table_number}{table number such as "B01001"}
+#'   \item{table_name}{description of table. A table has multiple columns (table_content)}
+#'   \item{universe}{the universe of the data}
+#' }
+#'
+#' @keywords datasets
+#'
+#' @source Check for each year of ACS 1-year and 5-year
+#' \href{https://www.census.gov/programs-surveys/acs/technical-documentation/summary-file-documentation.2018.html}{Sequence Number/Table Number Lookup File}.
+#'
+
+"lookup_acs5year_2018"
+
+
+
+
 # lookup_acs5year_2017 =========================================================
 #' ACS 5-year 2017 file segment and table lookup data
 #'
