@@ -526,8 +526,8 @@ search_tables <- function(survey, years = NULL, keywords = NULL, view = TRUE){
         # generated in data_raw/acs with read_acsxyear()
         dt <- dict_acs5_table
         if (!is.null(years)){
-            if (min(years) < 2009 | max(years) > 2016){
-                message("Only 2009 - 2016 are available for acs 5 year surveys.")
+            if (min(years) < 2009 | max(years) > 2018){
+                message("Only 2009 - 2018 are available for acs 5 year surveys.")
                 return(NULL)
             }
 
@@ -538,8 +538,8 @@ search_tables <- function(survey, years = NULL, keywords = NULL, view = TRUE){
     } else if (survey == "acs1"){
         dt <- dict_acs1_table
         if (!is.null(years)){
-            if (min(years) < 2005 | max(years) > 2017){
-                message("Only 2005 - 2017 are available for acs 1 year surveys.")
+            if (min(years) < 2005 | max(years) > 2018){
+                message("Only 2005 - 2018 are available for acs 1 year surveys.")
                 return(NULL)
             }
 
@@ -705,6 +705,7 @@ generate_acs5_tablecontents_ <- function(){
     acs5_2015 <- modify_lookup_table_(5, 2015)
     acs5_2016 <- modify_lookup_table_(5, 2016)
     acs5_2017 <- modify_lookup_table_(5, 2017)
+    acs5_2018 <- modify_lookup_table_(5, 2018)
 
     dict_acs_tablecontent <- reduce(list(acs5_2009,
                                          acs5_2010,
@@ -714,7 +715,8 @@ generate_acs5_tablecontents_ <- function(){
                                          acs5_2014,
                                          acs5_2015,
                                          acs5_2016,
-                                         acs5_2017),
+                                         acs5_2017,
+                                         acs5_2018),
                                     merge, by = "reference", all = TRUE) %>%
 
         # add the following lines for year since 2013
@@ -733,10 +735,13 @@ generate_acs5_tablecontents_ <- function(){
         .[!is.na(acs5_2017), ":=" (table_content = content_acs5_2017,
                                    table_name = name_acs5_2017,
                                    universe = universe_acs5_2017)] %>%
+        .[!is.na(acs5_2018), ":=" (table_content = content_acs5_2018,
+                                   table_name = name_acs5_2018,
+                                   universe = universe_acs5_2018)] %>%
 
         # include all years and surveys
         .[, .(reference, table_content, table_name,
-              acs5_2017, acs5_2016, acs5_2015, acs5_2014,
+              acs5_2018, acs5_2017, acs5_2016, acs5_2015, acs5_2014,
               acs5_2013, acs5_2012, acs5_2011,
               acs5_2010, acs5_2009,
               universe)]
